package com.netsitech.caricese.paper.token;

import java.math.BigInteger;
import java.util.Date;

/**
 * Programma che genera gli url di login tramite token a partie dai dati di un utente e una chiave di generazione token
 * Per i dettagli sull'uso si veda l'help integrato nel codice
 * 
 * NB: Codice duplicato da utility paper per poter rilasciare il sorgente a terze parti  
 */
public class TokenCmdLineGenerator {

	public static void main(String[] args) throws Exception {
		new TokenCmdLineGenerator().runMain(args);
	}

	@SuppressWarnings("static-method")
	public void runMain(String[] args) throws Exception {

		int abi;
		int codiceFiliale;
		String matricola;
		String profilo;
		Date dataOra;
		BigInteger E;
		BigInteger N;

		if (args.length == 0 || "/? /h -h --help help".contains(args[1].toLowerCase())) {
			System.out.println("P@PAER v1.0.0");
			System.out.println("Utility command-line per la generazione di Token di sicurezza");
			System.out.println("USO: " + System.getProperty("sun.java.command") + " <abi> <codice filiale> <matricola> <profilo> <E> <N>");
			System.out.println();
			return;
		}

		try {
			abi = Integer.parseInt(args[0]);
			codiceFiliale = Integer.parseInt(args[1]);
			matricola = args[2];
			profilo = args[3];
			dataOra = new Date();

			E = new BigInteger(args[4]);
			N = new BigInteger(args[5]);
		} catch (Exception e) {
			throw new Exception("Errore durante la decodifica dei parametri", e);
		}

		System.out.println("Valori del token:");
		System.out.println("ABI       = " + abi);
		System.out.println("FILIALE   = " + codiceFiliale);
		System.out.println("MATRICOLA = " + matricola);
		System.out.println("PROFILO   = " + profilo);
		System.out.println("DATA/ORA  = " + dataOra);
		System.out.println();

		try {
			Token token = new Token(codiceFiliale, abi, matricola, Token.Profile.valueOf(profilo));

			String cryptedToken = TokenFunctions.encode(token, E, N);

			System.out.println("URL LOGIN");
			System.out.println();
			System.out.println("https://www.caricese.it/paper/tokenlogin.do?abi=" + abi + "&token=" + cryptedToken);
			System.out.println();
			System.out.println("http://crcspapert1.caricese.netsitech.com:9080/paper/tokenlogin.do?abi=" + abi + "&token=" + cryptedToken);
			System.out.println();
			System.out.println("http://localhost:9080/paper/tokenlogin.do?abi=" + abi + "&token=" + cryptedToken);
			System.out.println();
		} catch (Exception e) {
			throw new Exception("Errore durante la generazione del token", e);
		}
	}

}
